@@ -60,6 +60,14 @@ class Basket(models.Model):
 
         return key
 
+    @property
+    def signature(self):
+        """return an md5 of the basket and contents"""
+        hashes = ''.join([b.signature for b in self.basketitem_set.all()])
+        sig = hashlib.md5()
+        sig.update(hashes)
+        return sig.hexdigest()
+
     def total_price(self):
         """return the total price for the items in the basket"""
         # get the key
@@ -409,6 +417,18 @@ class BasketItem(models.Model):
         except KeyError:
             pass
 
+    @property
+    def signature(self):
+        sig_string = '{}{}{}{}'.format(
+            self.content_type,
+            self.object_id,
+            self.quantity,
+            self.get_options_hash(self.options.all())
+        )
+        sig = hashlib.md5()
+        sig.update(sig_string)
+        return sig.hexdigest()
+
     @staticmethod
     def get_options_hash(options):
         if len(options) == 0:
