@@ -47,7 +47,7 @@ def remove(request, basketitem_pk):
     return ajax.json_response(response)
 
 
-def update(request):
+def update(request, *kwargs):
     # next
     url = request.POST.get('next') or reverse('basky:basket')
 
@@ -77,6 +77,7 @@ def update(request):
 
                     # now update the quantity if > 0
                     if quantity > 0:
+
                         basket.add(
                             basketitem.content_object,
                             quantity=quantity,
